==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/HAZARDPRECAUTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour HAZARDPRECAUTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="HAZARDPRECAUTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HAZARDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRECAUTIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HAZARDPRECAUTIONID_Type", propOrder = {
    "hazardid",
    "precautionid"
})
public class HAZARDPRECAUTIONID_Type {

    @XmlElement(name = "HAZARDID", required = true)
    protected HAZARDID_Type hazardid;
    @XmlElement(name = "PRECAUTIONID", required = true)
    protected PRECAUTIONID_Type precautionid;

    /**
     * Obtient la valeur de la propriété hazardid.
     * 
     * @return
     *     possible object is
     *     {@link HAZARDID_Type }
     *     
     */
    public HAZARDID_Type getHAZARDID() {
        return hazardid;
    }

    /**
     * Définit la valeur de la propriété hazardid.
     * 
     * @param value
     *     allowed object is
     *     {@link HAZARDID_Type }
     *     
     */
    public void setHAZARDID(HAZARDID_Type value) {
        this.hazardid = value;
    }

    /**
     * Obtient la valeur de la propriété precautionid.
     * 
     * @return
     *     possible object is
     *     {@link PRECAUTIONID_Type }
     *     
     */
    public PRECAUTIONID_Type getPRECAUTIONID() {
        return precautionid;
    }

    /**
     * Définit la valeur de la propriété precautionid.
     * 
     * @param value
     *     allowed object is
     *     {@link PRECAUTIONID_Type }
     *     
     */
    public void setPRECAUTIONID(PRECAUTIONID_Type value) {
        this.precautionid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/HAZARDPRECAUTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for HAZARDPRECAUTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HAZARDPRECAUTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HAZARDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRECAUTIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HAZARDPRECAUTIONID_Type", propOrder = {
    "hazardid",
    "precautionid"
})
public class HAZARDPRECAUTIONID_Type {

    @XmlElement(name = "HAZARDID", required = true)
    protected HAZARDID_Type hazardid;
    @XmlElement(name = "PRECAUTIONID", required = true)
    protected PRECAUTIONID_Type precautionid;

    /**
     * Gets the value of the hazardid property.
     * 
     * @return
     *     possible object is
     *     {@link HAZARDID_Type }
     *     
     */
    public HAZARDID_Type getHAZARDID() {
        return hazardid;
    }

    /**
     * Sets the value of the hazardid property.
     * 
     * @param value
     *     allowed object is
     *     {@link HAZARDID_Type }
     *     
     */
    public void setHAZARDID(HAZARDID_Type value) {
        this.hazardid = value;
    }

    /**
     * Gets the value of the precautionid property.
     * 
     * @return
     *     possible object is
     *     {@link PRECAUTIONID_Type }
     *     
     */
    public PRECAUTIONID_Type getPRECAUTIONID() {
        return precautionid;
    }

    /**
     * Sets the value of the precautionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PRECAUTIONID_Type }
     *     
     */
    public void setPRECAUTIONID(PRECAUTIONID_Type value) {
        this.precautionid = value;
    }

}
